from django import forms
from django.contrib.auth.forms import AuthenticationForm
from .models import CustomUser

class RegisterForm(forms.ModelForm):
    
    password = forms.CharField(widget=(forms.PasswordInput(attrs={'type':'password', 'class':'form-control'})))
    confirm_password = forms.CharField(widget=(forms.PasswordInput(attrs={'type':'password', 'class':'form-control last'})))
    
    class Meta:
        model = CustomUser
        fields = ['username', 'email', 'profile_image', 'password', 'confirm_password']
        widgets = {
            'email':forms.EmailInput({'type':'email', 'class':'form-control'}),
            'username':forms.TextInput({'type':'text', 'class':'form-control'}),
            'profile_image':forms.ClearableFileInput({'class':'control'}),
        }
        labels = {
            'email':'Email Address',
        }

class LoginForm(AuthenticationForm):

    username = forms.CharField(widget=forms.TextInput(attrs={'class':'form-control'}))
    password = forms.CharField(widget=forms.PasswordInput(attrs={'class':'form-control'}))
    



# Generated by Django 5.1.7 on 2025-03-12 10:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0012_alter_user_first_name_max_length'),
        ('users', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='customuser',
            name='profile_image',
            field=models.ImageField(blank=True, default='profile_pictures/8.png', null=True, upload_to='profile_pics/'),
        ),
        migrations.AlterField(
            model_name='customuser',
            name='groups',
            field=models.ManyToManyField(blank=True, related_name='Customuser_set', to='auth.group'),
        ),
        migrations.AlterField(
            model_name='customuser',
            name='user_permissions',
            field=models.ManyToManyField(blank=True, related_name='CustomUser_permissions_set', to='auth.permission'),
        ),
    ]



from django.db import models
from django.contrib.auth.models import AbstractUser, Group, Permission

# Create your models here.

class CustomUser(AbstractUser):

    email = models.EmailField(unique=True)
    username = models.CharField(max_length=100, unique=True)
    profile_image = models.ImageField(upload_to='profile_pics/', default='profile_pictures/8.png', blank=True, null=True)
    
    groups = models.ManyToManyField(Group, related_name='Customuser_set', blank=True)
    
    user_permissions = models.ManyToManyField(Permission, related_name='CustomUser_permissions_set', blank=True)

    def __str__(self):
        return self.username


from django.db import models

# Create your models here.

class Category(models.Model):
    name = models.CharField(max_length=100, unique=True)

    def __str__(self):
        return self.name

class Item(models.Model):
    
    name = models.CharField(max_length=255)
    description = models.TextField(blank=True, null=True)
    price = models.DecimalField(max_digits=10, decimal_places=2)
    quantity = models.PositiveIntegerField(default=1)
    category = models.ForeignKey(Category, on_delete=models.SET_NULL, null=True)
    
    image = models.ImageField(upload_to='items/', default='items/127826165_p0_master1200.jpg', blank=True, null=True)

    def __str__(self):
        return self.name



from django.shortcuts import render, redirect
from django.contrib import messages
from django.contrib.auth import login, authenticate, logout
from django.contrib.auth.decorators import login_required
from django.contrib.auth.forms import AuthenticationForm

from .forms import RegisterForm, LoginForm

# Create your views here.

def index(request):
    return render(request, 'index.html')

def register(request):
    if request.method == "POST":
        form = RegisterForm(request.POST, request.FILES)
        if form.is_valid():
            user = form.save(commit=False)
            user.set_password(form.cleaned_data['password'])
            user.save()
            login(request, user)
            messages.success(request, f'Welcome {user.username}')
            return redirect('home')
        else:
            messages.error(request, f'{form.errors}')
    else:
        form = RegisterForm()
    
    return render(request, 'users/register.html', {'registerform':form})

def user_login(request):
    if request.method == "POST":
        form = LoginForm(data=request.POST)
        if form.is_valid():
            username = form.cleaned_data.get('username')
            password = form.cleaned_data.get('password')
            user = authenticate(request, username=username, password=password)
            if user is not None:
                login(request, user)
                messages.success(request, f'Wlecome back, {user.username}')
                return redirect('home')
            else:
                messages.error(request, 'Empty user!')
        else:
            messages.error(request, f'{form.errors}')
    else:
        form = LoginForm()
        
    return render(request, 'users/login.html', {'loginform':form})

def user_logout(request):
    logout(request)
    return redirect('index')    


@login_required
def home(request):
    user = request.user
    return render(request, 'home.html', {'user':user})


from django.urls import path
from django.conf.urls.static import static
from django.conf import settings

from . import views

urlpatterns = [
    path('', views.index, name='index'),
    path('register/', views.register, name='register'),
    path('login/', views.user_login, name='login'),
    path('logout/', views.user_logout, name='logout'),
    path('home/', views.home, name='home'),
]

if settings.DEBUG:
    urlpatterns += static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)


from django import forms
from .models import Item, Category

class ItemForm(forms.ModelForm):
    
    class Meta:
        model = Item
        fields = ['name', 'description', 'price', 'category', 'image']
        widgets = {
            'name':forms.TextInput({'class':'form-control'}),
            'price':forms.NumberInput({'class':'form-control'}),
            'category':forms.Select({'class':'form-control'}),
            'description': forms.Textarea(attrs={'rows': 2, 'class':'form-contro'}),
            'image': forms.FileInput(attrs={'class':'form-control last img'}),
        }
        labels = {
            'name': 'Item Name',
            'description': 'Item Description',
            'price': 'Item Price',
            'category': 'Item Category',
            'image': 'Item Image',
        }
        error_messages = {
            'name': {'required': 'Please enter the name of the item'},
            'description': {'required': 'Please enter the description of the item'},
            'price': {'required': 'Please enter the price of the item'},
            'category': {'required': 'Please select the category of the item'},
            'image': {'required': 'Please upload an image of the item'},
        }
        
        
class CategoryForm(forms.ModelForm):
    
    class Meta:
        model = Category
        fields = ['name']
        labels = {
            'name': 'Category Name',
        }
        help_texts = {
            'name': 'Enter the name of the category',
        }
        error_messages = {
            'name': {'required': 'Please enter the name of the category'},
        }



# Generated by Django 5.1.7 on 2025-03-12 10:52

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Category',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100, unique=True)),
            ],
        ),
        migrations.CreateModel(
            name='Item',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('description', models.TextField(blank=True, null=True)),
                ('price', models.DecimalField(decimal_places=2, max_digits=10)),
                ('quantity', models.PositiveIntegerField(default=1)),
                ('image', models.ImageField(blank=True, null=True, upload_to='items')),
                ('category', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='core.category')),
            ],
        ),
    ]



from django.urls import path
from django.conf.urls.static import static
from django.conf import settings

from . import views

app_name = "crudkit"

urlpatterns = [
    path('<str:app_label>/<str:model_name>/', views.read_items, name='crud-list'),
    path('<str:app_label>/<str:model_name>/<int:pk>/', views.item, name='crud-detail'),
    path('<str:app_label>/<str:model_name>/create/', views.create_item, name='crud-create'),
    path('<str:app_label>/<str:model_name>/<int:id>/update/', views.update_item, name='crud-update'),
    path('<str:app_label>/<str:model_name>/<int:id>/delete/', views.delete_item, name='crud-delete'),
    path('<tsr:app_label>/<str:model_name>/create_category/', views.create_category, name='create_category'),
]
if settings.DEBUG:
    urlpatterns += static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)





from setuptools import setup, find_packages

setup(
    name="django-crud-kit",  # Package name for PyPI
    version="0.1",
    packages=find_packages(),
    include_package_data=True,  # Ensures templates & static files are included
    install_requires=[
        "django>=4.0",
    ],
    classifiers=[
        "Framework :: Django",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    author="Koded",
    author_email="your-email@example.com",
    description="A reusable CRUD system for Django projects",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/Koded0214h/DjangoCrudKit",  # Your GitHub repo
    python_requires=">=3.6",
)



from django.shortcuts import render, redirect
from django.contrib.auth.decorators import login_required

from .forms import ItemForm, CategoryForm
from .models import Item, Category

# Create your views here.

@login_required
def create_item(request):
    if request.method == "POST":
        form = ItemForm(request.POST, request.FILES)
        if form.is_valid():
            form.save()
            return redirect('read_items')
    else:
        form = ItemForm()
    return render(request, 'core/create_item.html', {'form':form})
        

@login_required
def read_items(request):
    items = Item.objects.all()
    return render(request, 'core/read_items.html', {'items': items})

@login_required
def update_item(request, id):
    item = Item.objects.get(id=id)
    if request.method == 'POST':
        form = ItemForm(request.POST, request.FILES, instance=item)
        if form.is_valid():
            form.save()
            return redirect('read_items')
    else:
        form = ItemForm(instance=item)
    return render(request, 'core/update_item.html', {'form': form})

@login_required
def delete_item(request, id):
    item = Item.objects.get(id=id)
    item.delete()
    return redirect('read_items')

@login_required
def item(request, id):
    item = Item.objects.get(id=id)
    user = request.user
    return render(request, 'core/item.html', {'item':item, 'user':user})

@login_required
def create_category(request):
    if request.method == 'POST':
        form = CategoryForm(request.POST)
        if form.is_valid():
            form.save()
            return redirect('read_items')
    else:
        form = CategoryForm()
    return render(request, 'core/create_category.html', {'form': form})



